<?php
// $Id: profile_pictures.admin.inc,v 1.1 2010/04/09 20:27:27 yeputons Exp $
/**
 * @file
 *   Handlers for field edit form
 */

/**
 * Add/edit field form callback. 
 * Calls profile_field_form for default field types,
 * Or adds specific options for image fields (base field type - textfield)
 */
function profile_pictures_field_form(&$form_state, $path, $arg = NULL) {
  require_once $path;
  
  // First we need determine field type
  if ((arg(3) == 'edit') && is_numeric($arg)) {
    $fld = db_fetch_object(db_query('SELECT type FROM {profile_fields} WHERE (fid=%d)', $arg));
    $type = $fld->type;
    drupal_set_title(t('edit %title', array('%title' => $fld->title)));
  }
  else {
    $type = $arg;
    if ($type == 'picture') $arg = 'textfield';
  }
  if ($type != 'picture') return profile_field_form($form_state, $arg);
  $form = profile_field_form($form_state, $arg);

  if (!is_numeric($arg)) {
    drupal_set_title(t('add new %type', array('%type' => 'picture')));
  }

  // Copy-paste from profile.module
  if (isset($form['type'])) $form['type']['#value'] = 'picture';
  unset($form['fields']['page']);

  // Adding image options (dimensions, size)
  if (is_numeric($arg)) {
    $opts = unserialize(db_result(db_query('SELECT options FROM {profile_fields} WHERE (fid=%d)', $arg)));
  }
  $form['fields']['image'] = array(
    '#type' => 'fieldset',
    '#title' => t('Image properties'),
    'image_maxsize' => array(
      '#type' => 'textfield',
      '#title' => t('Maximum size of uploaded image (in KiB, zero if none)'),
      '#default_value' => $opts['maxsize'],
    ),
    'image_maxdim' => array(
      '#type' => 'textfield',
      '#title' => t('Maximum dimensions of uploaded image (WxH, in pixels)'),
      '#default_value' => $opts['maxw'] . 'x' . $opts['maxh'],
    ),
  );
  return $form;
}

/**
 * Calls profile_field_form_validate and validate 'max. dimensions' field format
 * for image fields
 */
function profile_pictures_field_form_validate($form, &$form_state) {
  $type = $form['#parameters'][2];
  if (is_numeric($type)) {
    $type = db_result(db_query('SELECT type FROM {profile_fields} WHERE (fid=%d)', $type));
  }

  if ($type == 'picture') {
    $maxsz = $form_state['values']['image_maxsize'];
    if (!is_numeric($maxsz) || ($maxsz < 0))
      form_set_error('image_maxsize', t('Please, enter an non-negative number'));

    if (!preg_match('/^([0-9]+)x([0-9]+)$/', $form_state['values']['image_maxdim'], $dim)
        || !is_numeric($maxw = $dim[1]) || !is_numeric($maxh = $dim[2]))
      form_set_error('image_maxdim', t('Please, input dimensions in format WxH'));

    $opts = array(
      'maxsize' => $maxsz,
      'maxw' => $maxw,
      'maxh' => $maxh,
    );
    $form_state['values']['options'] = serialize($opts);
  }
  profile_field_form_validate($form, $form_state);
}

/**
 * Just calls profile_field_form_submit to save changes
 */
function profile_pictures_field_form_submit($form, &$form_state) {
  profile_field_form_submit($form, $form_state);
}
